@@ -24,8 +24,7 @@ class AbstractInterface():
     self.__config = get_config()
     self.pre_init()
     self.__name = self.state['name']
-    self.show_state_dialog = not(self.__config.get_value('%s/show_state_dialog' % (self.__name.lower())))
-
+    self.__config_show_state_dialog = 'settings/%s/show-state-dialog' % (self.__name.lower())
     self.__button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
     self.__button.set_image(gtk.Image())
     self.__button.set_image_position(gtk.POS_LEFT)
@@ -108,10 +107,6 @@ class AbstractInterface():
     show_banner = False
     update_ui = False
     value, mode, strength = getattr(self, 'process_signal_%s' % key)(*args, **kwargs)
-
-    #print 'old', self.__name, self.state['value'], self.state['mode'], self.state['strength']
-    #print 'new', self.__name, value, mode, strength
-
     if value != None and value != self.state['value']:
       self.state['value'] = value
       show_banner = True
@@ -126,7 +121,6 @@ class AbstractInterface():
     if strength != None and strength != self.state['strength']:
       self.state['strength'] = strength
       update_ui = True
-    #print 'result', self.__name, self.state['value'], self.state['mode'], self.state['strength']
     if update_ui:
       self.__update_ui()
     windex = self.state['value']
@@ -135,7 +129,6 @@ class AbstractInterface():
       if len(self.state['modes']) > 1:
         text = '%s (%s)' % (text, self.__lcl.get_item(self.state['modes'][self.state['mode']]))
       HildonBanner.show_information(self.__button, text)
-#    print (self.__name, self.state['text'][self.state['value']], self.state['modes'][self.state['mode']])
 
   def __init_interfaces(self):
     for x in self.interfaces: self.__init_interface(x)
@@ -188,12 +181,10 @@ class AbstractInterface():
     self.__button.set_value(self.__lcl.get_item(self.state['text'][windex]))
 
   def __button_clicked(self, button=None, user_data=None):
-    self.__switch(self.show_state_dialog)
-    return True
+    return self.__switch(self.__config.get_value(self.__config_show_state_dialog))
 
   def __button_tap_and_hold(self, button=None, user_data=None):
-    self.__switch(not(self.show_state_dialog))
-    return True
+    return self.__switch(not(self.__config.get_value(self.__config_show_state_dialog)))
 
   def __switch(self, show_dialog):
     if not self.__processing:
